/* $Id: whole.pl,v 1.3 2001/09/17 16:01:51 diaz Exp $ */

:-	include('read_file.pl').
:-	include('bip_list.pl').
:-	include('syn_sugar.pl').
:-	include('internal.pl').
:-	include('code_gen.pl').
:-	include('reg_alloc.pl').
:-	include('inst_codif.pl').
:-	include('first_arg.pl').
:-	include('indexing.pl').
:-	include('wam_emit.pl').
:-	include('pl2wam.pl').
